<?php 

$lang['title'] = 'Встановлення/Видалення модулів';

$lang['module_installed'] = 'Встановлено';
$lang['module_removed'] = 'Видалено';

$lang['ln_install'] = 'Встановити';
$lang['ln_remove'] = 'Видалити';

$lang['res_name'] = 'Модуль';
$lang['res_alias'] = 'Псевдонім';

$lang['msg_install'] = 'Встановити модуль ';
$lang['msg_uninstall'] = 'Видалити модуль ';

$lang['Return to list'] = '< Повернутись до списку';

$lang['Remove module from ACL'] = 'Видалити модуль з ACL';
$lang['Drop module tables'] = 'Видалить таблиці модуля';
$lang['Module was installed'] = 'Модуль встановлено';
$lang['Module was removed'] = 'Модуль видалено';