<ul class="nav nav-list">
    <li class="nav-header">{ln_menu_title}</li>
    <li class="divider"></li>
    {item}
    <li class="{class}"><a href="javascript:void(0);">{name}</a></li>
    {/item}
</ul>