<?php 

$config['export_config_file_path'] = 'vendor/ciext/ciext/config/export';

$config['check_folders'] = array(
    'application/cache',
    'application/config',
    'application/logs',
    'application/modules',
    'assets/uploads'
);

$config['auto_installing_modules'] = array(
    'resmng',
    'ciext_help',
    'cache',
    'filemanager',
    'seo',
    'inlineeditor',
    'emailmng',
    'sitemap',
    'site_menu',
);
