<?php

return [
    'project_modules'         => [
        'label'        => 'Описание модулей проекта',
        'position'     => 5,
        'file'         => __DIR__ . '/../docs/project_modules.md',
        'acl_resource' => 'ciext_help',
        'acl_action'   => 'view_ciext_user_guide',
    ],
    'english_project_modules' => [
        'label'        => 'Project Modules Description',
        'position'     => 5,
        'file'         => __DIR__ . '/../docs/english/project_modules.md',
        'language'     => 'english',
        'acl_resource' => 'ciext_help',
        'acl_action'   => 'view_ciext_user_guide',
    ],
    'ciext_acl'               => [
        'label'        => 'Управление доступом',
        'file'         => __DIR__ . '/../docs/acl/ciext_acl.md',
        'position'     => 30,
        'pages'        => [
            'role' => [
                'label'        => 'Роль',
                'file'         => __DIR__ . '/../docs/acl/role.md',
                'position'     => 10,
                'acl_resource' => 'acl',
                'acl_action'   => 'view_role',
            ],
            'rule' => [
                'label'        => 'Правила',
                'file'         => __DIR__ . '/../docs/acl/rule.md',
                'position'     => 20,
                'acl_resource' => 'acl',
                'acl_action'   => 'edit_rule',
            ],
            'user' => [
                'label'    => 'Пользователь',
                'file'     => __DIR__ . '/../docs/acl/user.md',
                'position' => 30,
            ],
        ],
        'acl_resource' => 'acl',
        'acl_action'   => 'view_user',
    ],
    'ciext_settings'          => [
        'label'        => 'Настройки',
        'file'         => __DIR__ . '/../docs/settings/ciext_settings.md',
        'position'     => 40,
        'pages'        => [
            'settings' => [
                'label'    => 'Общие настройки системы',
                'file'     => __DIR__ . '/../docs/settings/settings_system.md',
                'position' => 10,
            ],
        ],
        'acl_resource' => 'system',
        'acl_action'   => 'system_settings',
    ],
    'translate_mng_user'      => [
        'label'        => 'Менеджер переводов',
        'file'         => __DIR__ . '/../docs/lang/tr_mng_user.md',
        'position'     => 45,
        'acl_resource' => 'system',
        'acl_action'   => 'translate_manager',
    ],
    'developer_docs'          => [
        'label'        => 'Документация разработчику',
        'file'         => __DIR__ . '/../docs/welcome.md',
        'position'     => 900,
        'acl_resource' => 'ciext_help',
        'acl_action'   => 'view_programmer_docs',
        'pages'        => [
            'ciext_install'    => [
                'label'    => 'Установка/перенос проекта',
                'file'     => __DIR__ . '/../docs/install.md',
                'position' => 5,
            ],
            'module_structure' => [
                'label'    => 'Структура модуля',
                'file'     => __DIR__ . '/../docs/module_structure/module_structure.md',
                'position' => 10,
                'pages'    => [
                    'module_config'      => [
                        'label'    => 'config',
                        'file'     => __DIR__ . '/../docs/module_structure/config/config.md',
                        'position' => 10,
                        'pages'    => [
                            'bootstrap_php' => [
                                'label'    => 'bootstrap.php',
                                'file'     => __DIR__ . '/../docs/module_structure/config/bootstrap_php.md',
                                'position' => 10,
                            ],
                            'upgrade_php'   => [
                                'label'    => 'upgrade.php',
                                'file'     => __DIR__ . '/../docs/module_structure/config/upgrade_php.md',
                                'position' => 20,
                            ],
                        ]
                    ],
                    'module_controllers' => [
                        'label'    => 'controllers',
                        'file'     => __DIR__ . '/../docs/module_structure/controllers/controllers.md',
                        'position' => 20,
                        'pages'    => [
                            'c_install' => [
                                'label'    => 'install',
                                'file'     => __DIR__ . '/../docs/module_structure/controllers/c_install.md',
                                'position' => 10,
                            ],
                            'c_admin'   => [
                                'label'    => 'admin',
                                'file'     => __DIR__ . '/../docs/module_structure/controllers/c_admin.md',
                                'position' => 20,
                            ],
                            'c_site'    => [
                                'label'    => 'site',
                                'file'     => __DIR__ . '/../docs/module_structure/controllers/c_site.md',
                                'position' => 30,
                            ],
                        ]
                    ],
                    'module_data'        => [
                        'label'    => 'data',
                        'file'     => __DIR__ . '/../docs/module_structure/data/data.md',
                        'position' => 30,
                        'pages'    => [
                            'install_sql' => [
                                'label'    => 'install_sql',
                                'file'     => __DIR__ . '/../docs/module_structure/data/install.md',
                                'position' => 10,
                            ]
                        ]
                    ],
                    'module_language'    => [
                        'label'    => 'language',
                        'file'     => __DIR__ . '/../docs/module_structure/language/language.md',
                        'position' => 40,
                    ],
                    'module_libraries'   => [
                        'label'    => 'libraries',
                        'file'     => __DIR__ . '/../docs/module_structure/libraries/libraries.md',
                        'position' => 50,
                        'pages'    => [
                            'module_migrations' => [
                                'label'    => 'migrations',
                                'file'     => __DIR__ . '/../docs/module_structure/libraries/migrations.md',
                                'position' => 10,
                            ]
                        ],
                    ],
                    'module_models'      => [
                        'label'    => 'models',
                        'file'     => __DIR__ . '/../docs/module_structure/models/models.md',
                        'position' => 60,
                    ],
                    'module_viwes'       => [
                        'label'    => 'viewes',
                        'file'     => __DIR__ . '/../docs/module_structure/viwes/viwes.md',
                        'position' => 70,
                    ]
                ],
            ],
            'abstract_class'   => [
                'label'    => 'Абстрактные классы',
                'file'     => __DIR__ . '/../docs/abstract_class/abstract_class.md',
                'position' => 40,
                'pages'    => [
                    'abs_controller' => [
                        'label'    => 'Controllers',
                        'file'     => __DIR__ . '/../docs/abstract_class/controllers/abs_controller.md',
                        'position' => 10,
                        'pages'    => [
                            'absrtractauthcontroller'   => [
                                'label'    => 'AbsrtractAuthController',
                                'file'     => __DIR__ . '/../docs/abstract_class/controllers/absrtractauthcontroller.md',
                                'position' => 10,
                            ],
                            'absrtractjsoncontroller'   => [
                                'label'    => 'AbsrtractJsonController',
                                'file'     => __DIR__ . '/../docs/abstract_class/controllers/absrtractjsoncontroller.md',
                                'position' => 20,
                            ],
                            'abstractadmincontroller'   => [
                                'label'    => 'AbstractAdminController',
                                'file'     => __DIR__ . '/../docs/abstract_class/controllers/abstractadmincontroller.md',
                                'position' => 30,
                            ],
                            'abstractinstallcontroller' => [
                                'label'    => 'AbstractInstallController',
                                'file'     => __DIR__ . '/../docs/abstract_class/controllers/abstractinstallcontroller.md',
                                'position' => 40,
                            ],
                        ]
                    ],
                    'abs_form'       => [
                        'label'    => 'Forms',
                        'file'     => __DIR__ . '/../docs/abstract_class/forms/abs_form.md',
                        'position' => 20,
                        'pages'    => [
                            'abstractform' => [
                                'label'    => 'AbstractForm',
                                'file'     => __DIR__ . '/../docs/abstract_class/forms/abstractform.md',
                                'position' => 10,
                            ],
                        ]
                    ],
                    'abs_model'      => [
                        'label'    => 'Models',
                        'file'     => __DIR__ . '/../docs/abstract_class/models/abs_model.md',
                        'position' => 30,
                        'pages'    => [
                            'abstracteventmodel' => [
                                'label'    => 'AbstractEventModel',
                                'file'     => __DIR__ . '/../docs/abstract_class/models/abstracteventmodel.md',
                                'position' => 10,
                            ],
                            'abstracttablemodel' => [
                                'label'    => 'AbstractTableModel',
                                'file'     => __DIR__ . '/../docs/abstract_class/models/abstracttablemodel.md',
                                'position' => 20,
                            ],
                            'tablemodelfactory'  => [
                                'label'    => 'TableModelFactory',
                                'file'     => __DIR__ . '/../docs/abstract_class/models/tablemodelfactory.md',
                                'position' => 30,
                            ],
                        ]
                    ],
                    'abs_libraries'  => [
                        'label'    => 'Libraries',
                        'file'     => __DIR__ . '/../docs/abstract_class/libraries/abs_libraries.md',
                        'position' => 40,
                        'pages'    => [
                            'abstract_upgrade' => [
                                'label'    => 'AbstractUpgrade',
                                'file'     => __DIR__ . '/../docs/abstract_class/libraries/abstract_upgrade.md',
                                'position' => 10,
                            ],
                        ]
                    ],
                ]
            ],
            'core'             => [
                'label'    => 'Ядро системы',
                'file'     => __DIR__ . '/../docs/core/index.md',
                'position' => 50,
                'pages'    => [
                    'core_model' => [
                        'label'    => 'core_model',
                        'file'     => __DIR__ . '/../docs/core/core_model.md',
                        'position' => 20,
                    ],
                    'loader'     => [
                        'label'    => 'loader',
                        'file'     => __DIR__ . '/../docs/core/loader.md',
                        'position' => 30,
                    ],
                ]
            ],
            'multilang'        => [
                'label'    => 'Мультиязычность',
                'file'     => __DIR__ . '/../docs/libraries/index_multilang.md',
                'position' => 30,
                'pages'    => [
                    'db_lang_lib'   => [
                        'label'    => 'db_lang_lib',
                        'file'     => __DIR__ . '/../docs/libraries/db_lang_lib.md',
                        'position' => 30,
                    ],
                    'dev_translate' => [
                        'label'    => 'Менеджер переводов (translate)',
                        'file'     => __DIR__ . '/../docs/libraries/dev_translate.md',
                        'position' => 40,
                    ],
                    'translate_mng' => [
                        'label'    => 'Добавление нового языкового пакета',
                        'file'     => __DIR__ . '/../docs/lang/tr_mng.md',
                        'position' => 50,
                    ],
                ]
            ],
            'media_work'       => [
                'label'    => 'Работа с медиа',
                'file'     => __DIR__ . '/../docs/libraries/media.md',
                'position' => 40,
                'pages'    => [
                    'js_css'      => [
                        'label'    => 'js и css файлы (js_css)',
                        'file'     => __DIR__ . '/../docs/libraries/js_css.md',
                        'position' => 10,
                    ],
                    'core_assets' => [
                        'label'    => 'Минимизация js и css файлов, less',
                        'file'     => __DIR__ . '/../docs/core/assets.md',
                        'position' => 20,
                    ],
                    'image'       => [
                        'label'    => 'Изображения',
                        'file'     => __DIR__ . '/../docs/libraries/image.md',
                        'position' => 30,
                    ],
                ],
            ],
            'configurator'     => [
                'label'    => 'Конфигураторы',
                'file'     => __DIR__ . '/../docs/libraries/configurator_about.md',
                'position' => 50,
                'pages'    => [
                    'system_configurator' => [
                        'label'    => 'Конфигуратор системы',
                        'file'     => __DIR__ . '/../docs/core/system_configurator.md',
                        'position' => 10,
                    ],
                    'configurator_mod'    => [
                        'label'    => 'Конфигуратор',
                        'file'     => __DIR__ . '/../docs/libraries/configurator.md',
                        'position' => 20,
                    ]
                ]
            ],
            'core_parsers'     => [
                'label'    => 'Парсеры системы',
                'file'     => __DIR__ . '/../docs/parsers/index.md',
                'position' => 60,
                'pages'    => [
                    'core_parser_add_css'      => [
                        'label'    => 'Добавление css файла (add_css)',
                        'file'     => __DIR__ . '/../docs/parsers/add_css.md',
                        'position' => 10,
                    ],
                    'core_parser_add_js'       => [
                        'label'    => 'Добавление js файла (add_js)',
                        'file'     => __DIR__ . '/../docs/parsers/add_js.md',
                        'position' => 10,
                    ],
                    'core_parser_configurator' => [
                        'label'    => 'Возвращает данные с настроек модуля (configurator)',
                        'file'     => __DIR__ . '/../docs/parsers/configurator.md',
                        'position' => 10,
                    ],
                    'core_parser_page_url'     => [
                        'label'    => 'Возвращает путь к странице (page_url)',
                        'file'     => __DIR__ . '/../docs/parsers/page_url.md',
                        'position' => 10,
                    ],
                    'core_parser_date'         => [
                        'label'    => 'Вывод даты согласно формата (date)',
                        'file'     => __DIR__ . '/../docs/parsers/date.md',
                        'position' => 10,
                    ],
                    'core_parser_safe_mailto'  => [
                        'label'    => 'Безопасный email (safe_mailto)',
                        'file'     => __DIR__ . '/../docs/parsers/safe_mailto.md',
                        'position' => 20,
                    ],
                    'core_parser_module'       => [
                        'label'    => 'Вызов метода контроллера модуля (module)',
                        'file'     => __DIR__ . '/../docs/parsers/module.md',
                        'position' => 10,
                    ],
                    'core_parser_include'      => [
                        'label'    => 'Загрузка содержимого файла (include)',
                        'file'     => __DIR__ . '/../docs/parsers/include.md',
                        'position' => 10,
                    ],
                ]
            ],
        ],
    ],
];
