<?php
// CRUD add new buttons
$lang['add_new_page'] = 'new page';
$lang['add_new_template'] = 'new template';
$lang['add_new_menu'] = 'new menu';

$lang['crud_image'] = 'Image';
$lang['crud_page'] = 'Page';
$lang['crud_content'] = 'Content';
$lang['crud_template'] = 'Template';
$lang['crud_menu'] = 'Menu';
$lang['crud_parent_id'] = 'Parent element';
$lang['crud_view_order'] = 'View order';
$lang['active'] = 'Active';

